@@ -8,9 +8,9 @@ import javax.xml.bind.annotation.XmlRootElement;
 import javax.xml.bind.annotation.XmlType;
 import com.openexchange.admin.soap.context.dataobjects.Context;
 import com.openexchange.admin.soap.context.dataobjects.Credentials;
+import com.openexchange.admin.soap.context.dataobjects.SchemaSelectStrategy;
 import com.openexchange.admin.soap.context.dataobjects.User;
 
-
 /**
  * <p>Java-Klasse f\u00fcr anonymous complex type.
  *
@@ -18,16 +18,17 @@ import com.openexchange.admin.soap.context.dataobjects.User;
  *
  * <pre>
  * &lt;complexType>
- *   &lt;complexContent>
- *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
- *       &lt;sequence>
- *         &lt;element name="ctx" type="{http://dataobjects.soap.admin.openexchange.com/xsd}Context" minOccurs="0"/>
- *         &lt;element name="admin_user" type="{http://dataobjects.soap.admin.openexchange.com/xsd}User" minOccurs="0"/>
- *         &lt;element name="access_combination_name" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
- *         &lt;element name="auth" type="{http://dataobjects.rmi.admin.openexchange.com/xsd}Credentials" minOccurs="0"/>
- *       &lt;/sequence>
- *     &lt;/restriction>
- *   &lt;/complexContent>
+ * &lt;complexContent>
+ * &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
+ * &lt;sequence>
+ * &lt;element name="ctx" type="{http://dataobjects.soap.admin.openexchange.com/xsd}Context" minOccurs="0"/>
+ * &lt;element name="admin_user" type="{http://dataobjects.soap.admin.openexchange.com/xsd}User" minOccurs="0"/>
+ * &lt;element name="access_combination_name" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
+ * &lt;element name="auth" type="{http://dataobjects.rmi.admin.openexchange.com/xsd}Credentials" minOccurs="0"/>
+ * &lt;element name="auth" type="{http://dataobjects.rmi.admin.openexchange.com/xsd}SchemaSelectStrategy" minOccurs="0"/>
+ * &lt;/sequence>
+ * &lt;/restriction>
+ * &lt;/complexContent>
  * &lt;/complexType>
  * </pre>
  *
@@ -38,7 +39,8 @@ import com.openexchange.admin.soap.context.dataobjects.User;
     "ctx",
     "adminUser",
     "accessCombinationName",
-    "auth"
+    "auth",
+    "schemaSelectStrategy"
 })
 @XmlRootElement(name = "createModuleAccessByName")
 public class CreateModuleAccessByName {
@@ -51,13 +53,14 @@ public class CreateModuleAccessByName {
     protected String accessCombinationName;
     @XmlElement(nillable = true)
     protected Credentials auth;
+    @XmlElement(name = "schema_select_strategy", nillable = true)
+    private SchemaSelectStrategy schemaSelectStrategy;
 
     /**
      * Ruft den Wert der ctx-Eigenschaft ab.
      *
      * @return
-     *     possible object is
-     *     {@link Context }
+     *         possible object is {@link Context }
      *
      */
     public Context getCtx() {
@@ -68,8 +71,7 @@ public class CreateModuleAccessByName {
      * Legt den Wert der ctx-Eigenschaft fest.
      *
      * @param value
-     *     allowed object is
-     *     {@link Context }
+     *            allowed object is {@link Context }
      *
      */
     public void setCtx(Context value) {
@@ -80,8 +82,7 @@ public class CreateModuleAccessByName {
      * Ruft den Wert der adminUser-Eigenschaft ab.
      *
      * @return
-     *     possible object is
-     *     {@link User }
+     *         possible object is {@link User }
      *
      */
     public User getAdminUser() {
@@ -92,8 +93,7 @@ public class CreateModuleAccessByName {
      * Legt den Wert der adminUser-Eigenschaft fest.
      *
      * @param value
-     *     allowed object is
-     *     {@link User }
+     *            allowed object is {@link User }
      *
      */
     public void setAdminUser(User value) {
@@ -104,8 +104,7 @@ public class CreateModuleAccessByName {
      * Ruft den Wert der accessCombinationName-Eigenschaft ab.
      *
      * @return
-     *     possible object is
-     *     {@link String }
+     *         possible object is {@link String }
      *
      */
     public String getAccessCombinationName() {
@@ -116,8 +115,7 @@ public class CreateModuleAccessByName {
      * Legt den Wert der accessCombinationName-Eigenschaft fest.
      *
      * @param value
-     *     allowed object is
-     *     {@link String }
+     *            allowed object is {@link String }
      *
      */
     public void setAccessCombinationName(String value) {
@@ -128,8 +126,7 @@ public class CreateModuleAccessByName {
      * Ruft den Wert der auth-Eigenschaft ab.
      *
      * @return
-     *     possible object is
-     *     {@link Credentials }
+     *         possible object is {@link Credentials }
      *
      */
     public Credentials getAuth() {
@@ -140,12 +137,29 @@ public class CreateModuleAccessByName {
      * Legt den Wert der auth-Eigenschaft fest.
      *
      * @param value
-     *     allowed object is
-     *     {@link Credentials }
+     *            allowed object is {@link Credentials }
      *
      */
     public void setAuth(Credentials value) {
         this.auth = value;
     }
 
+    /**
+     * Returns the schema select strategy.
+     * 
+     * @return The {@link SchemaSelectStrategy}
+     */
+    public SchemaSelectStrategy getSchemaSelectStrategy() {
+        return schemaSelectStrategy;
+    }
+
+    /**
+     * Sets the schema select strategy.
+     * 
+     * @param schemaSelectStrategy The {@link SchemaSelectStrategy}
+     */
+    public void setSchemaSelectStrategy(SchemaSelectStrategy schemaSelectStrategy) {
+        this.schemaSelectStrategy = schemaSelectStrategy;
+    }
+
 }
